@@ -35,8 +35,42 @@ here = os.path.abspath(os.path.dirname(__file__))
 import shutil
 
 USER_HOME_DIR = os.path.dirname( os.path.expanduser('~/') )
+# if USER_HOME_DIR.find(' ') >= 0 and sys.platform == 'win32':
+#     ROCKETCEA_DATA_DIR = os.path.join( os.path.split(USER_HOME_DIR)[0], 'Public', 'RocketCEA' )
+# else:
 ROCKETCEA_DATA_DIR = os.path.join( USER_HOME_DIR, 'RocketCEA' )
 
+# may need to add DLL directory to allow pyd/dll import
+if hasattr(os, 'add_dll_directory'):
+    os.add_dll_directory( here )
+
+
+# from rocketcea.short_win_path import get_short_path_name
+from rocketcea.short_win_path import get_usable_path
+
+def set_rocketcea_data_dir( rddir, do_print=True ):
+    """
+    Set working data directory for RocketCEA. 
+    On Windows will correct for any spaces in path name.
+    Also useful to make a local working directory outside the USER_HOME_DIR.
+    """
+    global ROCKETCEA_DATA_DIR
+    ROCKETCEA_DATA_DIR = rddir
+    if do_print:
+        print( 'Setting ROCKETCEA_DATA_DIR =', ROCKETCEA_DATA_DIR )
+    # try to solve spaces in Windows Path names by making 8.3, short path names.
+    if ROCKETCEA_DATA_DIR.find(' ') >= 0:
+        print('WARNING: ROCKETCEA_DATA_DIR contains space characters:')
+        print('   ',ROCKETCEA_DATA_DIR)
+        ROCKETCEA_DATA_DIR = get_usable_path( ROCKETCEA_DATA_DIR )
+        
+set_rocketcea_data_dir( ROCKETCEA_DATA_DIR, do_print=False )
+
+def get_rocketcea_data_dir():
+    """Return the working data directory for RocketCEA"""
+    return ROCKETCEA_DATA_DIR
+
+
 # # python >=3.8 needs to be given permission to import DLL files.
 from rocketcea.find_mingw_lib import add_mingw_lib
 add_mingw_lib()
@@ -81,6 +115,14 @@ def getCacheDict():
     """Returns internal cache of previously called calculations."""
     return _CacheObjDict
 
+def clearCache( show_size=True ):
+    """Clear the cache of previously run cases for this session."""
+    if show_size:
+        print( 'BEFORE clearCache: Size of Cache =', len(_CacheObjDict))
+    _CacheObjDict.clear()
+    if show_size:
+        print( 'AFTER  clearCache: Size of Cache =', len(_CacheObjDict))
+
 def set_py_cea_line(N, line):
     '''make sure that trailing blanks are on added lines'''
     ln =  line + " "
@@ -96,6 +138,11 @@ def add_new_card( name, card_str, propD ):
     #: card_str = a single multiline string containing CEA input card for new propellant
     #: propD = dictionary to receive new propellant (e.g. oxCards, fuelCards or propCards)
     """
+    
+    # if name is already in propD, empty out the memoized run cache
+    # (i.e. if propellant is redefined, then old runs are not accurate)
+    if name in propD:
+        _CacheObjDict.clear()
 
     sL = card_str.split('\n')
     cardL = []
@@ -180,12 +227,13 @@ class CEA_Obj(object):
     """
 
     def __init__(self, propName='', oxName='', fuelName='', fac_CR=None,
-        useFastLookup=0, # depricated
+        useFastLookup=0, # deprecated
         makeOutput=0, make_debug_prints=False):
         """
         #: Create the base CEA wrapper object.
-        #: Fast Lookup is depricated.
+        #: Fast Lookup is deprecated.
         #: fac_CR = Contraction Ratio of finite area combustor (None=infinite)
+        #: makeOutput = flag to generate standard CEA text file output (default=0 for speed)
         #: if make_debug_prints is True, print debugging info to terminal.
         """
 
@@ -391,6 +439,9 @@ class CEA_Obj(object):
         #: frozen flag (0=equilibrium, 1=frozen)
         #: frozenAtThroat flag, 0=frozen in chamber, 1=frozen at throat
         '''
+        
+        # NOTE: if show_transport is True, need to set self.makeOutput to True
+        #       (i.e. transport properties require re-reading data from output file )
 
         global _last_called, _NLines_Max_ever
         
@@ -534,6 +585,7 @@ class CEA_Obj(object):
         if _NLines_Max_ever>N:
             while N<_NLines_Max_ever:
                 set_py_cea_line(N,"    ")
+                #set_py_cea_line(N," "*131)
                 N += 1
 
         # now call CEA
@@ -548,6 +600,12 @@ class CEA_Obj(object):
         except:
             print("ERROR reading data file for",self.desc)
 
+        if show_transport:
+            if self.make_debug_prints:
+                print("NOTE: transport properties require re-reading data from output file.")
+            readData = 1
+
+
         if readData:
             _last_called = self
             self.readDatafileOnce = 1
@@ -562,7 +620,12 @@ class CEA_Obj(object):
 
         if self.make_debug_prints:
             if self.makeOutput:
-                print("NOTICE... making an output file")
+                print('NOTICE... making an output file: f.out')
+                print("          in directory:", ROCKETCEA_DATA_DIR )
+                print()
+            print("==== CEA Input Deck ====")
+            for i_cea_deck in range( min(_NLines_Max_ever+1, 50) ):
+                print( py_cea.cet_inp.inplines[i_cea_deck].rstrip() )
 
         # Before calling CEA, init values to zero so bad run can be detected
         py_cea.rockt.vaci[ self.i_thrt ] =  0.0 # Vacuum Isp at throat
@@ -602,7 +665,18 @@ class CEA_Obj(object):
             
         #print( 'calling py_cea with pathPrefix and myfile=' )
         #print( '"'+self.pathPrefix+'"',' and ', '"'+myfile+'"' )
+        
+
+        save_makeOutput_flag = self.makeOutput
+        if show_transport:
+            # regardless of how run was set up, change makeOutput flag True
+            #   if transport properties are requested.
+            self.makeOutput = True
+        
         py_cea.py_cea(self.pathPrefix, myfile, self.makeOutput, readData)
+        
+        # restore user preference for makeOutput
+        self.makeOutput = save_makeOutput_flag
 
     def get_full_cea_output(self, Pc=100.0, MR=1.0, eps=40.0, subar=None, PcOvPe=None,
                             frozen=0, frozenAtThroat=0, short_output=0, show_transport=1,
@@ -620,7 +694,7 @@ class CEA_Obj(object):
         """
 
         # regardless of how run was set up, change makeOutput flag True
-        save_flag = self.makeOutput
+        save_makeOutput_flag = self.makeOutput
         self.makeOutput = True
         
         # Allow user to override fac_CR from CEA_Obj __init__
@@ -634,7 +708,7 @@ class CEA_Obj(object):
                          show_transport=show_transport, pc_units=pc_units,
                          output=output, show_mass_frac=show_mass_frac)
 
-        self.makeOutput = save_flag # restore makeOutput
+        self.makeOutput = save_makeOutput_flag # restore makeOutput
         self.fac_CR = save_fac_CR   # restore fac_CR
 
         return open( os.path.join(ROCKETCEA_DATA_DIR,'f.out'),'r').read()
@@ -1221,6 +1295,8 @@ class CEA_Obj(object):
         #: MR is only used for ox/fuel combos.
         #: eps = Nozzle Expansion Area Ratio
         #: frozen flag (0=equilibrium, 1=frozen)
+
+        NOTE: should return same value regardless of eps.
         """
         cpList = self.get_HeatCapacities( Pc=Pc, MR=MR, eps=eps, frozen=frozen)
         return cpList[ 0 ] # BTU/lbm degR  # 0 == self.i_chm here
@@ -1232,6 +1308,8 @@ class CEA_Obj(object):
         #: Pc = combustion end pressure (psia)
         #: MR is only used for ox/fuel combos.
         #: frozen = flag (0=equilibrium, 1=frozen)
+
+        NOTE: should return same value regardless of eps.
         """
         eps=1.0
         cacheDesc1 = (Pc,MR,eps,frozen,0) # set frozen flag to zero in cache description
@@ -1481,7 +1559,7 @@ class CEA_Obj(object):
         
         return Cp, visc, cond, Prandtl
 
-    def get_Exit_Transport(self, Pc=100.0, MR=1.0, eps=40.0, frozen=0):
+    def get_Exit_Transport(self, Pc=100.0, MR=1.0, eps=40.0, frozen=0, frozenAtThroat=0):
         """::
 
         #: Return a list of heat capacity, viscosity, thermal conductivity and Prandtl number
@@ -1491,7 +1569,8 @@ class CEA_Obj(object):
         #: eps = Nozzle Expansion Area Ratio
         #: frozen flag (0=equilibrium, 1=frozen)
         """
-        self.setupCards( Pc=Pc, MR=MR, eps=eps, show_transport=1)
+        self.setupCards( Pc=Pc, MR=MR, eps=eps, show_transport=1, 
+                         frozen=frozen, frozenAtThroat=frozenAtThroat)
         
         if frozen:
             Cp = py_cea.trpts.cpfro[ self.i_exit ]
@@ -1527,7 +1606,7 @@ def print_py_cea_vars():
 
 if __name__ == '__main__':
 
-    from pylab import *
+    # from pylab import *
 
 
     def showOutput( ispObj ):
@@ -1582,3 +1661,13 @@ if __name__ == '__main__':
 
             print('Pc=%4i  eps=%3i  IspAmb=%10.2f IspVac=%10.2f  Mode=%s'%(int(Pc),int(eps), IspAmb, IspVac, mode))
         print('  ---')
+
+    print( 'Checking get_Chamber_Cp calls')
+    print( C.get_Chamber_Cp( Pc=100.0, MR=1.0, eps=40.0, frozen=0) )
+    print( C.get_Chamber_Cp( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
+    print( C.get_Chamber_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=0) )
+    print( C.get_Chamber_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
+    print( C.get_Throat_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=0) )
+    print( C.get_Throat_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
+    print( C.get_Exit_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=0) )
+    print( C.get_Exit_Transport( Pc=100.0, MR=1.0, eps=40.0, frozen=1) )
